.. _source_code:

Source code structure
#####################

.. toctree::
   :maxdepth: 2

   source_mainfuncs
   source_utilfuncs
   source_fileiofuncs
   source_auxilfuncs

..   buildfuncs
   distfuncs
   fiofuncs
   auxfuncs
